@@ -3,7 +3,7 @@ package  Test::Hessian::Service::V2;
 use strict;
 use warnings;
 
-use base 'Test::Class';
+use parent 'Test::Hessian::Service';
 
 use Test::More;
 use Test::Deep;
@@ -13,11 +13,10 @@ use Hessian::Client;
 use YAML;
 use DateTime;
 use DateTime::Format::Strptime;
-##use Smart::Comments;
 
 my $test_service = 'http://hessian.caucho.com/test/test2';
 
-sub prep01_check_webservice : Test(startup) {    #{{{
+sub prep02_check_webservice : Test(startup) {
     my $self   = shift;
     my $client = Hessian::Client->new(
         {
@@ -33,9 +32,9 @@ sub prep01_check_webservice : Test(startup) {    #{{{
         $self->SKIP_ALL("Problem connecting to test service.");
     }
 
-}    #}}}
+}
 
-sub test_reply_int_0 : Test(1) {    #{{{
+sub test_reply_int_0 : Test(1) {
     my $self   = shift;
     my $client = Hessian::Client->new(
         {
@@ -45,9 +44,9 @@ sub test_reply_int_0 : Test(1) {    #{{{
     );
     my $result = $client->replyInt_0();
     is( $result->{reply_data}, 0 );
-}    #}}}
+}
 
-sub test_reply_int_47 : Test(1) {    #{{{
+sub test_reply_int_47 : Test(1) {
     my $self   = shift;
     my $client = Hessian::Client->new(
         {
@@ -57,9 +56,9 @@ sub test_reply_int_47 : Test(1) {    #{{{
     );
     my $result = $client->replyInt_47();
     is( $result->{reply_data}, 47 );
-}    #}}}
+}
 
-sub test_reply_int_mx800 : Test(1) {    #{{{
+sub test_reply_int_mx800 : Test(1) {
     my $self   = shift;
     my $client = Hessian::Client->new(
         {
@@ -70,9 +69,9 @@ sub test_reply_int_mx800 : Test(1) {    #{{{
     my $function = "replyInt_m0x800";
     my $result   = $client->$function();
     is( $result->{reply_data}, -0x800 );
-}    #}}}
+}
 
-sub test_reply_long_mOx80000000 : Test(1) {    #{{{
+sub test_reply_long_mOx80000000 : Test(1) {
     my $self   = shift;
     my $client = Hessian::Client->new(
         {
@@ -83,9 +82,9 @@ sub test_reply_long_mOx80000000 : Test(1) {    #{{{
     my $function = "replyLong_m0x80000000";
     my $result   = $client->$function();
     is( $result->{reply_data}, -0x80000000, 'Parsed correct long from server' );
-}    #}}}
+}
 
-sub test_reply_long_mOx80000001 : Test(1) {    #{{{
+sub test_reply_long_mOx80000001 : Test(1) {
     my $self   = shift;
     my $client = Hessian::Client->new(
         {
@@ -96,9 +95,9 @@ sub test_reply_long_mOx80000001 : Test(1) {    #{{{
     my $function = "replyLong_m0x80000001";
     my $result   = $client->$function();
     is( $result->{reply_data}, -0x80000001 );
-}    #}}}
+}
 
-sub test_reply_long_Ox10 : Test(1) {    #{{{
+sub test_reply_long_Ox10 : Test(1) {
     my $self   = shift;
     my $client = Hessian::Client->new(
         {
@@ -109,9 +108,9 @@ sub test_reply_long_Ox10 : Test(1) {    #{{{
     my $function = "replyLong_0x10";
     my $result   = $client->$function();
     is( $result->{reply_data}, 0x10 );
-}    #}}}
+}
 
-sub test_reply_double_0_0 : Test(1) {    #{{{
+sub test_reply_double_0_0 : Test(1) {
     my $self   = shift;
     my $client = Hessian::Client->new(
         {
@@ -122,9 +121,9 @@ sub test_reply_double_0_0 : Test(1) {    #{{{
     my $function = "replyDouble_0_0";
     my $result   = $client->$function();
     is( $result->{reply_data}, 0.0 );
-}    #}}}
+}
 
-sub test_reply_double_m0_001 : Test(1) {    #{{{
+sub test_reply_double_m0_001 : Test(1) {
     my $self   = shift;
     my $client = Hessian::Client->new(
         {
@@ -136,9 +135,9 @@ sub test_reply_double_m0_001 : Test(1) {    #{{{
     my $result   = $client->$function();
     local $TODO = 'Fix rounding differences on 32/64 bit machines.';
     is( $result->{reply_data}, -0.001, 'Parsed correct double from server.' );
-}    #}}}
+}
 
-sub test_reply_double_127_0 : Test(1) {    #{{{
+sub test_reply_double_127_0 : Test(1) {
     my $self   = shift;
     my $client = Hessian::Client->new(
         {
@@ -150,9 +149,9 @@ sub test_reply_double_127_0 : Test(1) {    #{{{
     my $result   = $client->$function();
     local $TODO = 'Fix rounding differences on 32/64 bit machines.';
     is( $result->{reply_data}, 127 );
-}    #}}}
+}
 
-sub test_reply_double_3_14159 : Test(1) {    #{{{
+sub test_reply_double_3_14159 : Test(1) {
     my $self   = shift;
     my $client = Hessian::Client->new(
         {
@@ -163,9 +162,9 @@ sub test_reply_double_3_14159 : Test(1) {    #{{{
     my $function = "replyDouble_3_14159";
     my $result   = $client->$function();
     is( $result->{reply_data}, 3.14159 );
-}    #}}}
+}
 
-sub test_reply_int_m17 : Test(1) {    #{{{
+sub test_reply_int_m17 : Test(1) {
     my $self   = shift;
     my $client = Hessian::Client->new(
         {
@@ -175,9 +174,9 @@ sub test_reply_int_m17 : Test(1) {    #{{{
     );
     my $result = $client->replyInt_m17();
     is( $result->{reply_data}, -17 );
-}    #}}}
+}
 
-sub reply_object_16 : Test(1) {    #{{{
+sub reply_object_16 : Test(1) {
     my $self           = shift;
     my $hessian_client = Hessian::Client->new(
         {
@@ -191,18 +190,18 @@ sub reply_object_16 : Test(1) {    #{{{
         { hessian_version => '2.0', reply_data => array_each( ignore() ) },
         "Received expected datastructure."
     );
-}    #}}}
+}
 
-sub reply_object_2b : Test(1) {    #{{{
+sub reply_object_2b : Test(1) {
     my $self   = shift;
     my $client = get_client();
     my $result = $client->replyObject_2b();
     my $array  = $result->{reply_data};
     cmp_deeply( $array->[0], $array->[1],
         "Received a two element array of the same object." );
-}    #}}}
+}
 
-sub reply_date_0 : Test(1) {    #{{{
+sub reply_date_0 : Test(1) {
     my $self = shift;
     my $date = DateTime->new(
         year      => 1970,
@@ -221,9 +220,9 @@ sub reply_date_0 : Test(1) {    #{{{
     my $result = $client->replyDate_0();
     is( DateTime->compare( $result->{reply_data}, $date ), 0 );
 
-}    #}}}
+}
 
-sub reply_date_1 : Test(1) {    #{{{
+sub reply_date_1 : Test(1) {
     my $self = shift;
     local $TODO = "2hr Discrepency in time calculation.";
     my $date = DateTime->new(
@@ -249,9 +248,9 @@ sub reply_date_1 : Test(1) {    #{{{
     my $result_date_iso = $formatter->format_datetime($result_date);
     ### datetime: $result_date_iso
 
-}    #}}}
+}
 
-sub reply_date_2 : Test(1) {    #{{{
+sub reply_date_2 : Test(1) {
     my $self = shift;
     local $TODO = "2hr Discrepency in time calculation.";
     my $date = DateTime->new(
@@ -270,9 +269,9 @@ sub reply_date_2 : Test(1) {    #{{{
     my $result_date_iso = $formatter->format_datetime($result_date);
     ### datetime: $result_date_iso
 
-}    #}}}
+}
 
-sub reply_untyped_fixed_list_7 : Test(1) {    #{{{
+sub reply_untyped_fixed_list_7 : Test(1) {
     my $self   = shift;
     my $client = get_client();
     my $result;
@@ -281,9 +280,9 @@ sub reply_untyped_fixed_list_7 : Test(1) {    #{{{
     }
     "No problems communicating with service.";
 
-}    #}}}
+}
 
-sub get_client {    #{{{
+sub get_client {
 
     my $client = Hessian::Client->new(
         {
@@ -292,7 +291,7 @@ sub get_client {    #{{{
         }
     );
     return $client;
-}    #}}}
+}
 
 "one, but we're not the same";
 
